import { IgrHorizontalAnchoredCategorySeries } from "./igr-horizontal-anchored-category-series";
import { PointSeries } from "./PointSeries";
/**
 * Represents a IgxDataChartComponent point series.
*
* You can use the `IgrPointSeries` plot a value along a category or date.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Date" />
*     <IgrNumericYAxis  name="yAxis" />
*    <IgrPointSeries
*     name="series1"
*     xAxisName="xAxis"
*     yAxisName="yAxis"
*     volumeMemberPath="Volume" />
*  </IgrDataChart>
* ```
*
* ```ts
* const series1 = new IgrPointSeries({ name: "series1" });
* series1.xAxisName = "xAxis";
* series1.yAxisName = "yAxis";
* series1.markerType = MarkerType.Circle;
* series1.valueMemberPath = "USA";
* ```
*/
export class IgrPointSeries extends IgrHorizontalAnchoredCategorySeries {
    createImplementation() {
        return new PointSeries();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Overridden by derived series classes to indicate when markerless display is preferred or not.
    */
    get isMarkerlessDisplayPreferred() {
        return this.i.cy;
    }
}
//# sourceMappingURL=igr-point-series.js.map
