import * as tslib_1 from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { CommodityChannelIndexIndicator } from "./CommodityChannelIndexIndicator";
/**
 * Represents a IgxDataChartComponent Commodity Channel Index indicator series.
 * Default required members: High, Low, Close
*
* `IgrCommodityChannelIndexIndicator` class specify the series as Commodity Channel Index Indicator series.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource} >
*
*     <IgrCategoryXAxis name="xAxis" label="Date" />
*     <IgrNumericYAxis  name="yAxis" />
*    <IgrCommodityChannelIndexIndicator
*     name="series1"
*     xAxisName="xAxis"
*     yAxisName="yAxis"
*     displayType="Line"
*     lowMemberPath="Low"
*     highMemberPath="High"
*     openMemberPath="Open"
*     closeMemberPath="Close"
*     volumeMemberPath="Volume" 	/>
*  </IgrDataChart>
* ```
*
* ```ts
* series1 = new IgrCommodityChannelIndexIndicator({ name: "colSeries1" });
* series1.dataSource = this.categoryData;
* series1.xAxis = this.categoryXAxis;
* series1.yAxis = this.numericYAxis;
* series1.xAxisName = "categoryXAxis";
* series1.yAxisName = "numericYAxis";
* series1.valueMemberPath = "Volume";
* series1.openMemberPath = "open";
* series1.highMemberPath = "high";
* series1.lowMemberPath = "low";
* series1.closeMemberPath = "close";
* ```
*/
var IgrCommodityChannelIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(IgrCommodityChannelIndexIndicator, _super);
    function IgrCommodityChannelIndexIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrCommodityChannelIndexIndicator.prototype.createImplementation = function () {
        return new CommodityChannelIndexIndicator();
    };
    Object.defineProperty(IgrCommodityChannelIndexIndicator.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCommodityChannelIndexIndicator.prototype, "period", {
        /**
         * Gets or sets the moving average period for the current CCISeries object.
         * The typical, and initial, value for CCI periods is 20.
        *
        * ```ts
        * this.series.period = 30;
        * ```
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource} >
        *
        *     <IgrCategoryXAxis name="xAxis" label="Date" />
        *     <IgrNumericYAxis  name="yAxis" />
        *    <IgrCommodityChannelIndexIndicator
        *     name="series3"
        *     xAxisName="xAxis"
        *     yAxisName="yAxis"
        *     displayType="Line"
        *     lowMemberPath="Low"
        *     highMemberPath="High"
        *     openMemberPath="Open"
        *     closeMemberPath="Close"
        *     volumeMemberPath="Volume"
        * 	period= {30}/>
        *  </IgrDataChart>
        * ```
        */
        get: function () {
            return this.i.qx;
        },
        set: function (v) {
            this.i.qx = +v;
        },
        enumerable: true,
        configurable: true
    });
    return IgrCommodityChannelIndexIndicator;
}(IgrStrategyBasedIndicator));
export { IgrCommodityChannelIndexIndicator };
//# sourceMappingURL=igr-commodity-channel-index-indicator.js.map
