import * as tslib_1 from "tslib";
import { IgrValueBrushScale } from "./igr-value-brush-scale";
import { IgrContourValueResolver } from "./igr-contour-value-resolver";
import { IgrScatterTriangulationSeries } from "./igr-scatter-triangulation-series";
import { ScatterContourSeries } from "./ScatterContourSeries";
/**
 * Series class for rendering isarithmic contours based on a triangulation of X+Y+Value points in the ItemsSource.
*/
var IgrScatterContourSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(IgrScatterContourSeries, _super);
    function IgrScatterContourSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrScatterContourSeries.prototype.createImplementation = function () {
        return new ScatterContourSeries();
    };
    Object.defineProperty(IgrScatterContourSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrScatterContourSeries.prototype, "valueMemberPath", {
        /**
         * Gets or set the name of the property from which to retrieve the numeric values from the ItemsSource items.
        */
        get: function () {
            return this.i.np;
        },
        set: function (v) {
            this.i.np = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrScatterContourSeries.prototype, "fillScale", {
        /**
         * Gets or sets the ValueBrushScale to use when determining Brushes for each contour line, based on the values found in ValueMemberPath.
        */
        get: function () {
            if (this.i.nk == null) {
                return null;
            }
            if (!this.i.nk.externalObject) {
                var e = IgrValueBrushScale._createFromInternal(this.i.nk);
                if (e) {
                    e._implementation = this.i.nk;
                }
                this.i.nk.externalObject = e;
            }
            return this.i.nk.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.nk = null : this.i.nk = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrScatterContourSeries.prototype, "valueResolver", {
        /**
         * Gets or set the ContourValueResolver used to determine the numeric values of contours.
        */
        get: function () {
            if (this.i.ni == null) {
                return null;
            }
            if (!this.i.ni.externalObject) {
                var e = IgrContourValueResolver._createFromInternal(this.i.ni);
                if (e) {
                    e._implementation = this.i.ni;
                }
                this.i.ni.externalObject = e;
            }
            return this.i.ni.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.ni = null : this.i.ni = v.i;
        },
        enumerable: true,
        configurable: true
    });
    IgrScatterContourSeries.prototype._styling = function (container, component, parent) {
        _super.prototype._styling.call(this, container, component, parent);
        this._inStyling = true;
        if (this.fillScale && this.fillScale._styling) {
            this.fillScale._styling(container, component, this);
        }
        if (this.valueResolver && this.valueResolver._styling) {
            this.valueResolver._styling(container, component, this);
        }
        this._inStyling = false;
    };
    IgrScatterContourSeries.prototype.getItemValue = function (item, memberPathName) {
        var iv = this.i.fs(item, memberPathName);
        return (iv);
    };
    return IgrScatterContourSeries;
}(IgrScatterTriangulationSeries));
export { IgrScatterContourSeries };
//# sourceMappingURL=igr-scatter-contour-series.js.map
