import { Type } from "igniteui-react-core";
/**
 * An enum representing the available collision modes of callout layers.
 */
export declare enum CalloutCollisionMode {
    /**
     * Automatically decide the collision strategy.
     */
    Auto = 0,
    /**
     * Use a simulated annealing based collision strategy. This is higher quality, but takes longer, and is performed time-sliced in the background until an acceptable quality is reached.
     */
    SimulatedAnnealing = 1,
    /**
     * Use a greedy algorithm to avoid collisions. This is cheap and predictable, but of comparatively low quality.
     */
    Greedy = 2,
    /**
     * Use a greedy algorithm with localized center of mass hints to avoid collisions. This is relatively cheap to perform, compared to the simulated annealing approach, but is of comparatively lower quality.
     */
    GreedyCenterOfMass = 3
}
/**
 * @hidden
 */
export declare let CalloutCollisionMode_$type: Type;
