import { IgPoint } from "igniteui-react-core";
import { IgrColorScale } from "./igr-color-scale";
import { IgrScatterTriangulationSeries, IIgrScatterTriangulationSeriesProps } from "./igr-scatter-triangulation-series";
import { ScatterAreaSeries } from "./ScatterAreaSeries";
/**
 * Series class which draws a colored 2D surface based on a triangulation of XY data with numeric values assigned to each point.
*/
export declare class IgrScatterAreaSeries extends IgrScatterTriangulationSeries<IIgrScatterAreaSeriesProps> {
    protected createImplementation(): ScatterAreaSeries;
    /**
                                 * @hidden
                                 */
    readonly i: ScatterAreaSeries;
    constructor(props: IIgrScatterAreaSeriesProps);
    /**
     * Gets or sets ColorScale used to resolve the color values of points in the series.
    */
    colorScale: IgrColorScale;
    /**
     * Gets or sets the name of the property on each data item containing a numeric value which can be converted to a color by the ColorScale.
    */
    colorMemberPath: string;
    protected _styling(container: any, component: any, parent?: any): void;
    getItemValue(item: any, memberPathName: string): any;
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world: IgPoint): any;
    /**
     * Attaches an image to the view of this series
    
    */
    attachImage(image: any): void;
}
export interface IIgrScatterAreaSeriesProps extends IIgrScatterTriangulationSeriesProps {
    /**
     * Gets or sets ColorScale used to resolve the color values of points in the series.
    */
    colorScale?: IgrColorScale;
    /**
     * Gets or sets the name of the property on each data item containing a numeric value which can be converted to a color by the ColorScale.
    */
    colorMemberPath?: string;
}
