import { IgrNumericXAxis } from "./igr-numeric-x-axis";
import { IgrNumericYAxis } from "./igr-numeric-y-axis";
import { IgrStyleShapeEventArgs } from "./igr-style-shape-event-args";
import { IgrSeries, IIgrSeriesProps } from "./igr-series";
import { ShapeSeriesBase } from "./ShapeSeriesBase";
import { IgrAxis } from "./igr-axis";
/**
 * Series class for rendering polygons.
*/
export declare abstract class IgrShapeSeriesBase<P extends IIgrShapeSeriesBaseProps = IIgrShapeSeriesBaseProps> extends IgrSeries<P> {
    /**
                                 * @hidden
                                 */
    readonly i: ShapeSeriesBase;
    constructor(props: P);
    /**
     * The name of the property on ItemsSource items which, for each shape, contains a list of points to be converted to a polygon.
     * To be consistent with the Shapefile technical description, it is expected that each list of points is defined as an IEnumerable of IEnumerable of Point, or in other words, a list of lists of points.
    */
    shapeMemberPath: string;
    /**
     * Gets or sets the effective x-axis for the current ScatterBase object.
    */
    xAxis: IgrNumericXAxis;
    private _xAxisName;
    /**
    * Gets or sets the name to use to resolve xAxis from markup.
    */
    xAxisName: string;
    /**
     * Gets or sets the effective y-axis for the current ScatterBase object.
    */
    yAxis: IgrNumericYAxis;
    private _yAxisName;
    /**
    * Gets or sets the name to use to resolve yAxis from markup.
    */
    yAxisName: string;
    /**
     * The resolution at which to filter out shapes in the series.  For example, if the ShapeFilterResolution is set to 3, then elements with a bounding rectangle smaller than 3 X 3 pixels will be filtered out.
     * In the case of ScatterPolylineSeries, the resolution is compared to either dimension, rather than both.  In other words, a polyline will not be filtered if its height or its width exceeds the value of this property.  Whereas with a ShapeSeries, both the height and the width must exceed the value of this property.
    */
    shapeFilterResolution: number;
    /**
     * Gets whether or not this series is a shape series
    */
    readonly isShape: boolean;
    bindAxes(axes: IgrAxis[]): void;
    protected _styling(container: any, component: any, parent?: any): void;
    getItemValue(item: any, memberPathName: string): any;
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    */
    canUseAsYAxis(axis: any): boolean;
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    canUseAsXAxis(axis: any): boolean;
    private _styleShape;
    private _styleShape_wrapped;
    /**
     * Raised when tile's image URI should be provided
    */
    styleShape: (s: IgrShapeSeriesBase, e: IgrStyleShapeEventArgs) => void;
}
export interface IIgrShapeSeriesBaseProps extends IIgrSeriesProps {
    /**
     * The name of the property on ItemsSource items which, for each shape, contains a list of points to be converted to a polygon.
     * To be consistent with the Shapefile technical description, it is expected that each list of points is defined as an IEnumerable of IEnumerable of Point, or in other words, a list of lists of points.
    */
    shapeMemberPath?: string;
    /**
     * Gets or sets the effective x-axis for the current ScatterBase object.
    */
    xAxis?: IgrNumericXAxis;
    /**
    * Gets or sets the name to use to resolve xAxis from markup.
    */
    xAxisName?: string;
    /**
     * Gets or sets the effective y-axis for the current ScatterBase object.
    */
    yAxis?: IgrNumericYAxis;
    /**
    * Gets or sets the name to use to resolve yAxis from markup.
    */
    yAxisName?: string;
    /**
     * The resolution at which to filter out shapes in the series.  For example, if the ShapeFilterResolution is set to 3, then elements with a bounding rectangle smaller than 3 X 3 pixels will be filtered out.
     * In the case of ScatterPolylineSeries, the resolution is compared to either dimension, rather than both.  In other words, a polyline will not be filtered if its height or its width exceeds the value of this property.  Whereas with a ShapeSeries, both the height and the width must exceed the value of this property.
    */
    shapeFilterResolution?: number | string;
    /**
     * Raised when tile's image URI should be provided
    */
    styleShape?: (s: IgrShapeSeriesBase, e: IgrStyleShapeEventArgs) => void;
}
